"use server";

import { revalidatePath } from "next/cache";

import { createAuthorization } from "@/lib/dto/authorization";
import { getAuthorizeUrl } from "@/lib/oauth/authorize-url";
import { prisma } from "@/lib/prisma";
import { getCurrentUser } from "@/lib/session";

// 检查平台级权限
async function checkPlatformAuthorization(clientId: string, userId: string) {
  // 检查应用是否被平台禁用
  const client = await prisma.client.findUnique({
    where: { id: clientId },
    select: { enabled: true },
  });

  if (!client) {
    return { allowed: false, error: "应用不存在" };
  }

  if (!client.enabled) {
    return { allowed: false, error: "该应用已被平台管理员禁用" };
  }

  // 检查用户授权是否被平台禁用
  const existingAuth = await prisma.authorization.findUnique({
    where: {
      userId_clientId: { userId, clientId },
    },
    select: { enabled: true },
  });

  if (existingAuth && !existingAuth.enabled) {
    return { allowed: false, error: "您的授权已被平台管理员禁用" };
  }

  return { allowed: true };
}

// 检查应用级权限
async function checkApplicationAuthorization(
  clientId: string,
  username: string,
) {
  const client = await prisma.client.findUnique({
    where: { id: clientId },
    select: { allowedUsers: true, name: true },
  });

  if (!client) {
    return { allowed: false, error: "应用不存在" };
  }

  const isAllowedByOwner =
    client.allowedUsers.length === 0 || client.allowedUsers.includes(username);

  if (!isAllowedByOwner) {
    return { allowed: false, error: "此应用不允许您登录，请联系应用所有者" };
  }

  return { allowed: true };
}

export async function handleAuthorizeAction(
  oauth: string,
  clientId: string,
  scope: string,
) {
  try {
    // 获取当前登录用户
    const currentUser = await getCurrentUser();
    if (!currentUser?.id) {
      return { error: "请先登录" };
    }

    const userId = currentUser.id;

    // 获取用户信息
    const user = await prisma.user.findUnique({
      where: { id: userId },
      select: { username: true },
    });

    if (!user) {
      return { error: "用户不存在" };
    }

    // 检查平台级权限
    const platformAuth = await checkPlatformAuthorization(clientId, userId);
    if (!platformAuth.allowed) {
      return { error: platformAuth.error };
    }

    // 检查应用级权限
    const appAuth = await checkApplicationAuthorization(
      clientId,
      user.username,
    );
    if (!appAuth.allowed) {
      return { error: appAuth.error };
    }

    // 使用事务处理授权记录的更新或创建
    await prisma.$transaction(async (tx) => {
      const existingAuth = await tx.authorization.findUnique({
        where: {
          userId_clientId: {
            userId,
            clientId,
          },
        },
      });

      if (existingAuth) {
        // 更新最后使用时间
        await tx.authorization.update({
          where: {
            userId_clientId: {
              userId,
              clientId,
            },
          },
          data: {
            lastUsedAt: new Date(),
          },
        });
      } else {
        // 创建新的授权记录
        await tx.authorization.create({
          data: {
            userId,
            clientId,
            scope,
            enabled: true,
            lastUsedAt: new Date(),
          },
        });
      }
    });

    // 处理重定向
    const oauthParams = new URLSearchParams(atob(oauth));
    const redirectUrl = getAuthorizeUrl(oauthParams);

    return { redirectUrl };
  } catch (error) {
    console.error("授权处理失败:", error);
    if (error instanceof Error) {
      return { error: `授权处理失败: ${error.message}` };
    }
    return { error: "授权处理失败，请稍后重试" };
  }
}
