"use client";

import { useState } from "react";
import { useRouter } from "next/navigation";
import type { ExtendedClient } from "@/types";
import type { Client } from "@prisma/client";

import {
  AlertDialog,
  AlertDialogAction,
  AlertDialogCancel,
  AlertDialogContent,
  AlertDialogDescription,
  AlertDialogFooter,
  AlertDialogHeader,
  AlertDialogTitle,
} from "@/components/ui/alert-dialog";
import { Label } from "@/components/ui/label";
import { Switch } from "@/components/ui/switch";

interface ClientStatusToggleProps {
  client: Client | ExtendedClient;
}

export function ClientStatusToggle({ client }: ClientStatusToggleProps) {
  const router = useRouter();
  const [isLoading, setIsLoading] = useState(false);
  const [showDialog, setShowDialog] = useState(false);
  const [pendingState, setPendingState] = useState<boolean | null>(null);

  const handleToggle = async () => {
    try {
      setIsLoading(true);
      const response = await fetch(`/api/admin/clients/${client.id}/status`, {
        method: "POST",
        headers: {
          "Content-Type": "application/json",
        },
        body: JSON.stringify({
          enabled: pendingState,
        }),
      });

      if (!response.ok) {
        throw new Error("Failed to update client status");
      }

      router.refresh();
    } catch (error) {
      console.error("Error updating client status:", error);
    } finally {
      setIsLoading(false);
      setShowDialog(false);
      setPendingState(null);
    }
  };

  return (
    <div className="flex items-center gap-2">
      <Switch
        checked={client.enabled}
        disabled={isLoading}
        onCheckedChange={(checked) => {
          setPendingState(checked);
          setShowDialog(true);
        }}
      />
      <Label className="text-sm text-muted-foreground">
        {client.enabled ? "已启用" : "已禁用"}
      </Label>

      <AlertDialog open={showDialog} onOpenChange={setShowDialog}>
        <AlertDialogContent>
          <AlertDialogHeader>
            <AlertDialogTitle>
              确定要{pendingState ? "启用" : "禁用"}该应用吗？
            </AlertDialogTitle>
            <AlertDialogDescription>
              {pendingState
                ? "启用后，该应用将恢复使用 OAuth 服务的权限。"
                : "禁用后，该应用将无法使用 OAuth 服务，所有已授权的用户将无法访问。"}
            </AlertDialogDescription>
          </AlertDialogHeader>
          <AlertDialogFooter>
            <AlertDialogCancel
              disabled={isLoading}
              onClick={() => setPendingState(null)}
            >
              取消
            </AlertDialogCancel>
            <AlertDialogAction
              onClick={handleToggle}
              disabled={isLoading}
              className={!pendingState ? "bg-destructive" : undefined}
            >
              确定
            </AlertDialogAction>
          </AlertDialogFooter>
        </AlertDialogContent>
      </AlertDialog>
    </div>
  );
}
