"use client";

import { useEffect, useState } from "react";
import Link from "next/link";
import { usePathname, useRouter } from "next/navigation";
import { ChevronDown, Menu, User } from "lucide-react";
import { signOut } from "next-auth/react";

import { cn } from "@/lib/utils";
import { Avatar, AvatarFallback, AvatarImage } from "@/components/ui/avatar";
import { Button } from "@/components/ui/button";
import {
  DropdownMenu,
  DropdownMenuContent,
  DropdownMenuItem,
  DropdownMenuTrigger,
} from "@/components/ui/dropdown-menu";

import { ThemeToggle } from "../theme-toggle";

interface HeaderClientProps {
  initialUser: any;
}

export function HeaderClient({ initialUser }: HeaderClientProps) {
  const [user, setUser] = useState(initialUser);
  const router = useRouter();
  const pathname = usePathname();

  const handleSignOut = async () => {
    await signOut({ redirect: false });
    setUser(null);
    router.refresh();
    router.push("/");
  };

  const renderNavLinks = () => {
    if (!user) return null;

    return (
      <div className="ml-8 hidden items-center space-x-1 md:flex">
        <Link
          href="/dashboard"
          className={cn(
            "rounded-md px-3 py-2 text-sm font-medium transition-colors hover:bg-accent hover:text-accent-foreground",
            pathname === "/dashboard"
              ? "bg-accent text-accent-foreground"
              : "text-muted-foreground",
          )}
        >
          控制台
        </Link>
        <Link
          href="/dashboard/clients"
          className={cn(
            "rounded-md px-3 py-2 text-sm font-medium transition-colors hover:bg-accent hover:text-accent-foreground",
            pathname.startsWith("/dashboard/clients")
              ? "bg-accent text-accent-foreground"
              : "text-muted-foreground",
          )}
        >
          应用管理
        </Link>
        <Link
          href="/dashboard/settings"
          className={cn(
            "rounded-md px-3 py-2 text-sm font-medium transition-colors hover:bg-accent hover:text-accent-foreground",
            pathname === "/dashboard/settings"
              ? "bg-accent text-accent-foreground"
              : "text-muted-foreground",
          )}
        >
          设置
        </Link>
        {user.role === "ADMIN" && (
          <>
            <div className="mx-2 h-4 w-px bg-border" />
            <Link
              href="/admin"
              className={cn(
                "rounded-md px-3 py-2 text-sm font-medium transition-colors hover:bg-accent hover:text-accent-foreground",
                pathname === "/admin"
                  ? "bg-accent text-accent-foreground"
                  : "text-muted-foreground",
              )}
            >
              管理后台
            </Link>
            <DropdownMenu>
              <DropdownMenuTrigger asChild>
                <Button
                  variant="ghost"
                  size="sm"
                  className={cn(
                    "rounded-md px-3 py-2 text-sm font-medium transition-colors hover:bg-accent hover:text-accent-foreground",
                    pathname.startsWith("/admin/") && pathname !== "/admin"
                      ? "bg-accent text-accent-foreground"
                      : "text-muted-foreground",
                  )}
                >
                  管理功能
                  <ChevronDown className="ml-1 h-4 w-4" />
                </Button>
              </DropdownMenuTrigger>
              <DropdownMenuContent align="start">
                <DropdownMenuItem asChild>
                  <Link
                    href="/admin/users"
                    className={cn(
                      "w-full",
                      pathname === "/admin/users" && "bg-accent",
                    )}
                  >
                    用户列表
                  </Link>
                </DropdownMenuItem>
                <DropdownMenuItem asChild>
                  <Link
                    href="/admin/clients"
                    className={cn(
                      "w-full",
                      pathname === "/admin/clients" && "bg-accent",
                    )}
                  >
                    应用管理
                  </Link>
                </DropdownMenuItem>
                <DropdownMenuItem asChild>
                  <Link
                    href="/admin/authorizations"
                    className={cn(
                      "w-full",
                      pathname === "/admin/authorizations" && "bg-accent",
                    )}
                  >
                    授权管理
                  </Link>
                </DropdownMenuItem>
                <DropdownMenuItem asChild>
                  <Link
                    href="/admin/logs"
                    className={cn(
                      "w-full",
                      pathname === "/admin/logs" && "bg-accent",
                    )}
                  >
                    系统日志
                  </Link>
                </DropdownMenuItem>
              </DropdownMenuContent>
            </DropdownMenu>
          </>
        )}
      </div>
    );
  };

  // 移动端导航菜单
  const renderMobileMenu = () => {
    if (!user) return null;

    return (
      <DropdownMenu>
        <DropdownMenuTrigger asChild>
          <Button variant="ghost" size="icon" className="md:hidden">
            <Menu className="h-5 w-5" />
          </Button>
        </DropdownMenuTrigger>
        <DropdownMenuContent align="end" className="w-64">
          <div className="flex items-center gap-3 border-b px-2 py-3">
            <Avatar className="h-8 w-8">
              <AvatarImage src={user.avatarUrl || undefined} />
              <AvatarFallback>
                {user.name?.charAt(0) || user.username?.charAt(0)}
              </AvatarFallback>
            </Avatar>
            <div className="flex flex-col">
              <span className="text-sm font-medium">
                {user.name || user.username}
              </span>
              <span className="text-xs text-muted-foreground">
                {user.email}
              </span>
            </div>
          </div>
          <DropdownMenuItem asChild>
            <Link
              href="/dashboard"
              className={cn("w-full", pathname === "/dashboard" && "bg-accent")}
            >
              控制台
            </Link>
          </DropdownMenuItem>
          <DropdownMenuItem asChild>
            <Link
              href="/dashboard/clients"
              className={cn(
                "w-full",
                pathname.startsWith("/dashboard/clients") && "bg-accent",
              )}
            >
              应用管理
            </Link>
          </DropdownMenuItem>
          <DropdownMenuItem asChild>
            <Link
              href="/dashboard/settings"
              className={cn(
                "w-full",
                pathname === "/dashboard/settings" && "bg-accent",
              )}
            >
              设置
            </Link>
          </DropdownMenuItem>
          {user.role === "ADMIN" && (
            <>
              <div className="my-1 h-px bg-border" />
              <DropdownMenuItem asChild>
                <Link
                  href="/admin"
                  className={cn("w-full", pathname === "/admin" && "bg-accent")}
                >
                  管理后台
                </Link>
              </DropdownMenuItem>
              <DropdownMenuItem asChild>
                <Link
                  href="/admin/users"
                  className={cn(
                    "w-full",
                    pathname === "/admin/users" && "bg-accent",
                  )}
                >
                  用户列表
                </Link>
              </DropdownMenuItem>
              <DropdownMenuItem asChild>
                <Link
                  href="/admin/clients"
                  className={cn(
                    "w-full",
                    pathname === "/admin/clients" && "bg-accent",
                  )}
                >
                  应用管理
                </Link>
              </DropdownMenuItem>
              <DropdownMenuItem asChild>
                <Link
                  href="/admin/authorizations"
                  className={cn(
                    "w-full",
                    pathname === "/admin/authorizations" && "bg-accent",
                  )}
                >
                  授权管理
                </Link>
              </DropdownMenuItem>
              <DropdownMenuItem asChild>
                <Link
                  href="/admin/logs"
                  className={cn(
                    "w-full",
                    pathname === "/admin/logs" && "bg-accent",
                  )}
                >
                  系统日志
                </Link>
              </DropdownMenuItem>
            </>
          )}
          <div className="my-1 h-px bg-border" />
          <DropdownMenuItem
            onClick={handleSignOut}
            className="text-red-600 focus:bg-red-50 focus:text-red-600 dark:focus:bg-red-950"
          >
            退出登录
          </DropdownMenuItem>
        </DropdownMenuContent>
      </DropdownMenu>
    );
  };

  return (
    <div className="flex items-center space-x-4">
      {renderNavLinks()}
      <ThemeToggle />
      {user ? (
        <>
          <div className="hidden items-center gap-3 md:flex">
            <Avatar className="h-8 w-8">
              <AvatarImage src={user.avatarUrl || undefined} />
              <AvatarFallback>
                {user.name?.charAt(0) || user.username?.charAt(0)}
              </AvatarFallback>
            </Avatar>
            <Button
              variant="ghost"
              size="sm"
              onClick={handleSignOut}
              className="text-muted-foreground hover:text-red-600"
            >
              退出
            </Button>
          </div>
          {renderMobileMenu()}
        </>
      ) : (
        <Button
          variant="outline"
          size="sm"
          className="border-[#25263A] text-[#25263A] hover:bg-[#25263A] hover:text-white dark:border-[#A0A1B2] dark:text-[#A0A1B2] dark:hover:bg-[#A0A1B2] dark:hover:text-[#25263A]"
          onClick={() => router.push("/sign-in")}
        >
          登录
        </Button>
      )}
    </div>
  );
}
